src/*
1
5
Done processing src/descriptor.pb.cc
Done processing src/descriptor.pb.h
Done processing src/descriptor_unittest.cc
Total errors found: 2376

src/descriptor.pb.cc:0:  No copyright message found.  You should have a line: "Copyright [year] <Copyright Owner>"  [legal/copyright] [5]
src/descriptor.pb.cc:9:  Found C system header after C++ system header. Should be: descriptor.pb.h, c system, c++ system, other.  [build/include_order] [4]
src/descriptor.pb.cc:10:  Found C system header after C++ system header. Should be: descriptor.pb.h, c system, c++ system, other.  [build/include_order] [4]
src/descriptor.pb.cc:11:  Found C system header after C++ system header. Should be: descriptor.pb.h, c system, c++ system, other.  [build/include_order] [4]
src/descriptor.pb.cc:12:  Found C system header after C++ system header. Should be: descriptor.pb.h, c system, c++ system, other.  [build/include_order] [4]
src/descriptor.pb.cc:13:  Found C system header after C++ system header. Should be: descriptor.pb.h, c system, c++ system, other.  [build/include_order] [4]
src/descriptor.pb.cc:14:  Found C system header after C++ system header. Should be: descriptor.pb.h, c system, c++ system, other.  [build/include_order] [4]
src/descriptor.pb.cc:15:  Found C system header after C++ system header. Should be: descriptor.pb.h, c system, c++ system, other.  [build/include_order] [4]
src/descriptor.pb.cc:16:  Found C system header after C++ system header. Should be: descriptor.pb.h, c system, c++ system, other.  [build/include_order] [4]
src/descriptor.pb.cc:17:  Found C system header after C++ system header. Should be: descriptor.pb.h, c system, c++ system, other.  [build/include_order] [4]
src/descriptor.pb.cc:22:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:24:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:26:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:27:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:28:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:29:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:30:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:32:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:34:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:36:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:38:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:39:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:40:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:41:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:42:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:43:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:44:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:46:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:48:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:50:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:52:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:54:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:56:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:58:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:60:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:61:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:62:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:64:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:65:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:66:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:68:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:69:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:70:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:81:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:82:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:84:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:85:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:90:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:91:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:95:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:96:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:97:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:98:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:99:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:100:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:101:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:102:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:103:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:104:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:105:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:118:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:119:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:122:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:123:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:126:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:127:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:130:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:131:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:135:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:141:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:143:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:144:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:146:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:147:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:158:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:159:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:163:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:164:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:166:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:167:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:168:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:169:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:170:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:171:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:182:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:183:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:187:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:190:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:191:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:196:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:200:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:201:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:204:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:205:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:206:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:210:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:211:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:214:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:215:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:216:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:220:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:221:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:224:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:225:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:226:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:227:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:228:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:229:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:237:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:241:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:242:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:243:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:244:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:247:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:248:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:249:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:251:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:252:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:253:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:255:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:273:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:274:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:276:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:277:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:280:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:287:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:296:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:305:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:308:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:311:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:316:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:320:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:321:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:322:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:324:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:325:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:329:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:330:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:333:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:337:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:341:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:342:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:346:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:347:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:350:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:351:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:354:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:355:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:359:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:360:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:361:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:362:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:363:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:364:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:372:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:373:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:376:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:377:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:378:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:379:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:380:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:387:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:392:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:393:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:396:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:397:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:398:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:399:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:404:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:405:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:408:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:442:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:443:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:444:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:445:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:446:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:447:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:448:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:449:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:450:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:451:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:452:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:453:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:454:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:455:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:456:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:457:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:458:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:459:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:460:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:461:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:462:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:463:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:464:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:465:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:466:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:467:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:476:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:575:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:577:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:579:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:581:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:583:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:585:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:587:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:589:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:591:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:597:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:606:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:617:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:631:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:632:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:633:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:637:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:639:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:641:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:642:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:643:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:645:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:648:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:653:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:657:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:663:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:664:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:667:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:677:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:679:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:683:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:687:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:689:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:690:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:692:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:694:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:695:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:698:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:700:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:702:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:706:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:709:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:712:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:720:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:723:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:725:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:726:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:727:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:730:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:735:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:736:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:746:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:749:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:751:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:760:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:813:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:836:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:905:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:980:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1001:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1004:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1009:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1056:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1058:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/descriptor.pb.cc:1068:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1106:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1139:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1169:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1173:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1186:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1232:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1234:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1236:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1238:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1240:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1242:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1250:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1259:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1260:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1261:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1272:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1273:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1274:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1298:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1317:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1321:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1325:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1347:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1350:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1401:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1414:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1427:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1440:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1452:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1463:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1474:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1475:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1478:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1479:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1490:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1491:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1494:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1495:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1638:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1640:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/descriptor.pb.cc:1740:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1773:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1786:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1869:  Redundant blank line at the end of a code block should be deleted.  [whitespace/blank_line] [3]
src/descriptor.pb.cc:1882:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1907:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1911:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1915:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1918:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1921:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1941:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1942:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1943:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1944:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:1992:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2001:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2008:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2014:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2026:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2031:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2039:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2054:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2063:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2070:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2076:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2081:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2088:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2093:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2101:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2120:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2128:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2167:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2171:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2175:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2197:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2201:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2227:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2231:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2244:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2257:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2261:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2274:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2287:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2291:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2299:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2304:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2317:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2321:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2329:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2334:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2357:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2374:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2396:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2399:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2402:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2404:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2412:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2419:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2441:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2450:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2457:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2463:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2468:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2475:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2480:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2488:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2509:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2540:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2545:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2550:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2574:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2577:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2583:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2596:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2631:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2636:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2646:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2648:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/descriptor.pb.cc:2652:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2657:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2661:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2691:  Redundant blank line at the end of a code block should be deleted.  [whitespace/blank_line] [3]
src/descriptor.pb.cc:2700:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2704:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2715:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2729:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2736:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2747:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2751:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2759:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2785:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2832:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2863:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2868:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2873:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2897:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2900:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2906:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2919:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2954:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2959:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2969:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2971:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/descriptor.pb.cc:2975:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2980:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:2984:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3014:  Redundant blank line at the end of a code block should be deleted.  [whitespace/blank_line] [3]
src/descriptor.pb.cc:3023:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3027:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3038:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3052:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3059:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3074:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3082:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3177:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3179:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3191:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3201:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3242:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3260:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3263:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3283:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3296:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3309:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3318:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3322:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3335:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3347:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3359:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3368:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3372:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3450:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3497:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3499:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/descriptor.pb.cc:3533:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3579:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3639:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3694:  Redundant blank line at the end of a code block should be deleted.  [whitespace/blank_line] [3]
src/descriptor.pb.cc:3707:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3733:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3736:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3756:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3757:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3758:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3759:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3760:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3806:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3815:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3822:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3828:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3840:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3845:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3853:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3864:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3868:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3876:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3881:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3894:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3898:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3906:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3911:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3924:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3928:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3941:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3954:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3958:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3971:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3984:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3988:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3992:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:3996:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4001:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4014:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4018:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4026:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4031:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4054:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4071:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4089:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4093:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4097:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4101:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4106:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4135:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4198:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4200:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4202:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4204:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4206:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4208:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4210:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4212:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4214:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4216:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4231:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4232:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4233:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4234:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4235:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4248:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4249:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4250:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4251:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4252:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4273:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4285:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4289:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4293:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4297:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4301:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4327:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4330:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4366:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4379:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4382:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4397:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4400:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4443:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4456:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4526:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4569:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4589:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4591:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/descriptor.pb.cc:4617:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4663:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4678:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4750:  Redundant blank line at the end of a code block should be deleted.  [whitespace/blank_line] [3]
src/descriptor.pb.cc:4764:  Redundant blank line at the end of a code block should be deleted.  [whitespace/blank_line] [3]
src/descriptor.pb.cc:4777:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4795:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4799:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4803:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4807:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4811:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4814:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4893:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4902:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4909:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4915:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4927:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4932:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4940:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4982:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:4986:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5007:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5011:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5029:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5038:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5045:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5051:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5056:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5063:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5068:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5076:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5091:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5100:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5107:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5113:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5118:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5125:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5130:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5138:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5153:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5162:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5169:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5175:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5180:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5187:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5192:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5194:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5200:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5239:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5248:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5255:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5261:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5266:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5273:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5278:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5286:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5307:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5324:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5358:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5360:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5372:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5382:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5403:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5415:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5433:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5436:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5455:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5511:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5513:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/descriptor.pb.cc:5534:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5564:  Redundant blank line at the end of a code block should be deleted.  [whitespace/blank_line] [3]
src/descriptor.pb.cc:5577:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5595:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5598:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5655:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5664:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5671:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5677:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5689:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5694:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5702:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5723:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5740:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5776:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5778:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5790:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5800:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5821:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5834:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5852:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5855:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5875:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5887:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5949:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:5951:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/descriptor.pb.cc:5979:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6020:  Redundant blank line at the end of a code block should be deleted.  [whitespace/blank_line] [3]
src/descriptor.pb.cc:6033:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6052:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6055:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6075:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6114:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6123:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6130:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6136:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6148:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6153:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6161:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6172:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6176:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6184:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6189:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6212:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6229:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6258:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6264:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6266:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6279:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6290:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6311:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6323:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6342:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6345:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6366:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6377:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6422:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6438:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6440:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/descriptor.pb.cc:6455:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6466:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6503:  Redundant blank line at the end of a code block should be deleted.  [whitespace/blank_line] [3]
src/descriptor.pb.cc:6512:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6516:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6534:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6537:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6545:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6598:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6607:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6614:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6620:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6632:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6637:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6645:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6687:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6690:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6692:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6700:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6707:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6736:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6743:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6745:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6757:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6767:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6788:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6801:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6819:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6822:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6842:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6854:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6916:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6918:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/descriptor.pb.cc:6946:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:6987:  Redundant blank line at the end of a code block should be deleted.  [whitespace/blank_line] [3]
src/descriptor.pb.cc:6996:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7000:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7019:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7022:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7042:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7081:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7090:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7097:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7103:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7115:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7120:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7128:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7139:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7143:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7147:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7151:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7156:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7176:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7179:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7196:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7234:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7236:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7238:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7240:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7242:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7244:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7259:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7260:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7261:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7272:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7273:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7274:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7295:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7307:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7311:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7315:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7324:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7337:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7340:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7389:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7402:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7415:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7486:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7491:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7501:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7503:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/descriptor.pb.cc:7547:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7552:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7556:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7610:  Redundant blank line at the end of a code block should be deleted.  [whitespace/blank_line] [3]
src/descriptor.pb.cc:7623:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7641:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7645:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7649:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7652:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7719:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7728:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7735:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7741:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7753:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7758:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7766:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7781:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7790:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7797:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7803:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7808:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7815:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7820:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7822:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7828:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7843:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7852:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7859:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7865:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7870:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7877:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7882:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7884:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7890:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7908:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7911:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:7928:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8026:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8028:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8030:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8032:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8034:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8036:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8038:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8040:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8042:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8044:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8046:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8048:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8058:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8059:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8060:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8061:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8062:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8063:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8064:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8075:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8076:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8077:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8078:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8079:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8080:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8112:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8116:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8120:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8124:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8128:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8132:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8137:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8138:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8141:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8142:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8155:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8158:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8180:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8189:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8194:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8197:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8212:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8240:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8253:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8266:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8279:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8292:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8305:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8318:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8332:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8371:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8375:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8427:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8434:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8442:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8457:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8462:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8467:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8472:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8477:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8482:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8487:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8539:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/descriptor.pb.cc:8555:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8563:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8571:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8587:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8592:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8597:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8602:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8607:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8612:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8617:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8665:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8746:  Redundant blank line at the end of a code block should be deleted.  [whitespace/blank_line] [3]
src/descriptor.pb.cc:8779:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8782:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8784:  Redundant blank line at the end of a code block should be deleted.  [whitespace/blank_line] [3]
src/descriptor.pb.cc:8817:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8821:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8825:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8829:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8833:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8837:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8890:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8907:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8940:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8949:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8956:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8962:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8967:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8974:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8979:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:8987:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9002:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9011:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9018:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9024:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9029:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9036:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9041:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9043:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9049:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9125:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9141:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9143:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9161:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9170:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9177:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9183:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9188:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9195:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9200:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9208:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9343:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9352:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9359:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9365:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9370:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9377:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9382:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9384:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9390:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9405:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9414:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9421:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9427:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9432:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9439:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9444:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9446:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9452:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9467:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9476:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9483:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9489:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9494:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9501:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9506:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9514:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9525:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9529:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9533:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9542:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9624:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9637:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9640:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9646:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9659:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9672:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9685:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9693:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9697:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9738:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9743:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9748:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9753:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9773:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9775:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/descriptor.pb.cc:9779:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9784:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9789:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9794:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9809:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9858:  Redundant blank line at the end of a code block should be deleted.  [whitespace/blank_line] [3]
src/descriptor.pb.cc:9871:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9893:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9923:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:9934:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10054:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10058:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10062:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10071:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10168:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10171:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10172:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10177:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10180:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10195:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10208:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10221:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10229:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10234:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10237:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10252:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10260:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10264:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10311:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10316:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10321:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10324:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10332:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10352:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10354:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/descriptor.pb.cc:10364:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10369:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10374:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10377:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10385:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10400:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10430:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10436:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10461:  Redundant blank line at the end of a code block should be deleted.  [whitespace/blank_line] [3]
src/descriptor.pb.cc:10532:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10611:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10715:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10719:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10723:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10732:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10814:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10817:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10818:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10822:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10878:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10880:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/descriptor.pb.cc:10894:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:10972:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11003:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11007:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11011:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11020:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11113:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11116:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11122:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11135:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11143:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11147:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11188:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11193:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11215:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/descriptor.pb.cc:11219:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11224:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11239:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11278:  Redundant blank line at the end of a code block should be deleted.  [whitespace/blank_line] [3]
src/descriptor.pb.cc:11337:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11418:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11422:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11426:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11435:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11498:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11521:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11524:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11530:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11538:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11542:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11583:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11603:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11605:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/descriptor.pb.cc:11609:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11624:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11669:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11710:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11766:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11770:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11774:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11783:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11869:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11872:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11878:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11886:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11890:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11931:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11951:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11953:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/descriptor.pb.cc:11957:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:11972:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12017:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12058:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12114:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12118:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12122:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12131:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12224:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12227:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12233:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12241:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12246:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12248:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12249:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12259:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12263:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12304:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12307:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12330:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12332:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/descriptor.pb.cc:12336:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12339:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12357:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12392:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12395:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12397:  Redundant blank line at the end of a code block should be deleted.  [whitespace/blank_line] [3]
src/descriptor.pb.cc:12456:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12506:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12520:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12522:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12524:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12538:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12542:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12546:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12555:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12578:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12584:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12586:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12594:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12604:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12612:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12617:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12622:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12633:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12647:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12650:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12671:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12716:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12726:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12728:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/descriptor.pb.cc:12743:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12747:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12781:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12800:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12804:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12815:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12822:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12830:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12837:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12853:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12880:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12889:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12896:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12902:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12905:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12907:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12914:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12919:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12921:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12927:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12984:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12986:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12988:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12990:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12992:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:12994:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13004:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13005:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13006:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13017:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13018:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13019:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13037:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13050:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13054:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13058:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13076:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13079:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13084:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13113:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13126:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13139:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13216:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13221:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13226:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13252:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13254:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/descriptor.pb.cc:13276:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13281:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13286:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13308:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13375:  Redundant blank line at the end of a code block should be deleted.  [whitespace/blank_line] [3]
src/descriptor.pb.cc:13388:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13407:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13411:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13415:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13444:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13480:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13484:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13488:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13492:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13497:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13514:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13523:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13530:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13536:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13541:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13548:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13553:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13555:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13561:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13583:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13607:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13648:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13657:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13664:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13670:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13675:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13682:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13687:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13689:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13695:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13710:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13719:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13726:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13732:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13737:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13744:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13749:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13751:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13757:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13781:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13790:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13792:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13794:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13796:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13803:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13804:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13813:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13814:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13832:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13847:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13851:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13865:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13868:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13872:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13873:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13876:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13877:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13888:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13889:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13892:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13893:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13922:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13937:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13938:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13940:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13974:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:13984:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14015:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14029:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14031:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/descriptor.pb.cc:14086:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14094:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14150:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14170:  Redundant blank line at the end of a code block should be deleted.  [whitespace/blank_line] [3]
src/descriptor.pb.cc:14179:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14183:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14204:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14208:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14213:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14238:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14265:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14295:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14325:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14334:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14341:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14347:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14350:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14352:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14359:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14364:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14366:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14372:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14387:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14394:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14396:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14403:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14409:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14412:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14414:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14421:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14426:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14428:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14434:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14445:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14449:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14453:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14457:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14461:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14470:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14478:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14479:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14567:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14570:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14575:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14622:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14624:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/descriptor.pb.cc:14634:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14672:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14734:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14738:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14746:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14751:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14776:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14783:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14785:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14795:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14806:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14814:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14819:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14824:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14836:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14853:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14856:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14860:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14861:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14864:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14865:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14893:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14906:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14941:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14961:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14966:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14976:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:14978:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/descriptor.pb.cc:15007:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:15012:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:15016:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:15072:  Redundant blank line at the end of a code block should be deleted.  [whitespace/blank_line] [3]
src/descriptor.pb.cc:15081:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:15085:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:15096:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:15104:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:15115:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:15122:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:15137:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:15166:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:15196:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:15205:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:15212:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:15218:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:15221:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:15223:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:15230:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:15235:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:15237:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:15243:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:15348:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:15369:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:15372:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:15377:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:15424:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:15426:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/descriptor.pb.cc:15436:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:15474:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:15536:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:15540:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:15544:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:15548:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:15553:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.cc:15237:  Add #include <string> for string  [build/include_what_you_use] [4]
src/descriptor.pb.cc:15518:  Add #include <utility> for swap  [build/include_what_you_use] [4]
src/descriptor.pb.cc:5:  samples/protobuf-sample/src/descriptor.pb.cc should include its header file samples/protobuf-sample/src/descriptor.pb.h  [build/include] [5]
src/descriptor.pb.h:0:  No copyright message found.  You should have a line: "Copyright [year] <Copyright Owner>"  [legal/copyright] [5]
src/descriptor.pb.h:4:  #ifndef header guard has wrong style, please use: SAMPLES_PROTOBUF_SAMPLE_SRC_DESCRIPTOR_PB_H_  [build/header_guard] [5]
src/descriptor.pb.h:7714:  #endif line should be "#endif  // SAMPLES_PROTOBUF_SAMPLE_SRC_DESCRIPTOR_PB_H_"  [build/header_guard] [5]
src/descriptor.pb.h:9:  Found C system header after C++ system header. Should be: descriptor.pb.h, c system, c++ system, other.  [build/include_order] [4]
src/descriptor.pb.h:37:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:87:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:88:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:89:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:91:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:92:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:98:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:107:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:108:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:109:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:111:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:112:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:118:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:127:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:128:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:129:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:131:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:132:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:147:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:148:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:151:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:167:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:168:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:169:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:171:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:172:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:183:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:225:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:227:  private: should be indented +1 space inside class FileDescriptorSet  [whitespace/indent] [3]
src/descriptor.pb.h:227:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:232:  private: should be indented +1 space inside class FileDescriptorSet  [whitespace/indent] [3]
src/descriptor.pb.h:232:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:239:  public: should be indented +1 space inside class FileDescriptorSet  [whitespace/indent] [3]
src/descriptor.pb.h:239:  "public:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:240:  Do not leave a blank line after "public:"  [whitespace/blank_line] [3]
src/descriptor.pb.h:254:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:256:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:261:  Do not leave a blank line after "private:"  [whitespace/blank_line] [3]
src/descriptor.pb.h:265:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:266:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:275:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:317:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:319:  private: should be indented +1 space inside class FileDescriptorProto  [whitespace/indent] [3]
src/descriptor.pb.h:319:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:324:  private: should be indented +1 space inside class FileDescriptorProto  [whitespace/indent] [3]
src/descriptor.pb.h:324:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:331:  public: should be indented +1 space inside class FileDescriptorProto  [whitespace/indent] [3]
src/descriptor.pb.h:331:  "public:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:332:  Do not leave a blank line after "public:"  [whitespace/blank_line] [3]
src/descriptor.pb.h:376:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:412:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:422:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:424:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:434:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:436:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:446:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:448:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:467:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:500:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:501:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:502:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:503:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:504:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:505:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:509:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:518:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:525:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:560:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:562:  private: should be indented +1 space inside class DescriptorProto_ExtensionRange  [whitespace/indent] [3]
src/descriptor.pb.h:562:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:567:  private: should be indented +1 space inside class DescriptorProto_ExtensionRange  [whitespace/indent] [3]
src/descriptor.pb.h:567:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:574:  public: should be indented +1 space inside class DescriptorProto_ExtensionRange  [whitespace/indent] [3]
src/descriptor.pb.h:574:  "public:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:575:  Do not leave a blank line after "public:"  [whitespace/blank_line] [3]
src/descriptor.pb.h:608:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:617:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:624:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:659:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:661:  private: should be indented +1 space inside class DescriptorProto_ReservedRange  [whitespace/indent] [3]
src/descriptor.pb.h:661:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:666:  private: should be indented +1 space inside class DescriptorProto_ReservedRange  [whitespace/indent] [3]
src/descriptor.pb.h:666:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:673:  public: should be indented +1 space inside class DescriptorProto_ReservedRange  [whitespace/indent] [3]
src/descriptor.pb.h:673:  "public:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:674:  Do not leave a blank line after "public:"  [whitespace/blank_line] [3]
src/descriptor.pb.h:707:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:758:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:760:  private: should be indented +1 space inside class DescriptorProto  [whitespace/indent] [3]
src/descriptor.pb.h:760:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:765:  private: should be indented +1 space inside class DescriptorProto  [whitespace/indent] [3]
src/descriptor.pb.h:765:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:772:  public: should be indented +1 space inside class DescriptorProto  [whitespace/indent] [3]
src/descriptor.pb.h:772:  "public:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:773:  Do not leave a blank line after "public:"  [whitespace/blank_line] [3]
src/descriptor.pb.h:802:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:804:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:814:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:816:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:828:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:838:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:840:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:843:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:847:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:848:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:850:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:852:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:862:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:864:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:880:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:881:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:883:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:885:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:901:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:915:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:916:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:917:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:918:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:919:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:920:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:922:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:924:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:933:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:975:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:977:  private: should be indented +1 space inside class FieldDescriptorProto  [whitespace/indent] [3]
src/descriptor.pb.h:977:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:982:  private: should be indented +1 space inside class FieldDescriptorProto  [whitespace/indent] [3]
src/descriptor.pb.h:982:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:989:  public: should be indented +1 space inside class FieldDescriptorProto  [whitespace/indent] [3]
src/descriptor.pb.h:989:  "public:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:990:  Do not leave a blank line after "public:"  [whitespace/blank_line] [3]
src/descriptor.pb.h:1216:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:1225:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:1267:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:1269:  private: should be indented +1 space inside class OneofDescriptorProto  [whitespace/indent] [3]
src/descriptor.pb.h:1269:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:1274:  private: should be indented +1 space inside class OneofDescriptorProto  [whitespace/indent] [3]
src/descriptor.pb.h:1274:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:1281:  public: should be indented +1 space inside class OneofDescriptorProto  [whitespace/indent] [3]
src/descriptor.pb.h:1281:  "public:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:1282:  Do not leave a blank line after "public:"  [whitespace/blank_line] [3]
src/descriptor.pb.h:1310:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:1319:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:1361:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:1363:  private: should be indented +1 space inside class EnumDescriptorProto  [whitespace/indent] [3]
src/descriptor.pb.h:1363:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:1368:  private: should be indented +1 space inside class EnumDescriptorProto  [whitespace/indent] [3]
src/descriptor.pb.h:1368:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:1375:  public: should be indented +1 space inside class EnumDescriptorProto  [whitespace/indent] [3]
src/descriptor.pb.h:1375:  "public:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:1376:  Do not leave a blank line after "public:"  [whitespace/blank_line] [3]
src/descriptor.pb.h:1402:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:1404:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:1427:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:1429:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:1438:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:1445:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:1480:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:1482:  private: should be indented +1 space inside class EnumValueDescriptorProto  [whitespace/indent] [3]
src/descriptor.pb.h:1482:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:1487:  private: should be indented +1 space inside class EnumValueDescriptorProto  [whitespace/indent] [3]
src/descriptor.pb.h:1487:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:1494:  public: should be indented +1 space inside class EnumValueDescriptorProto  [whitespace/indent] [3]
src/descriptor.pb.h:1494:  "public:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:1495:  Do not leave a blank line after "public:"  [whitespace/blank_line] [3]
src/descriptor.pb.h:1545:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:1554:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:1596:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:1598:  private: should be indented +1 space inside class ServiceDescriptorProto  [whitespace/indent] [3]
src/descriptor.pb.h:1598:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:1603:  private: should be indented +1 space inside class ServiceDescriptorProto  [whitespace/indent] [3]
src/descriptor.pb.h:1603:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:1610:  public: should be indented +1 space inside class ServiceDescriptorProto  [whitespace/indent] [3]
src/descriptor.pb.h:1610:  "public:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:1611:  Do not leave a blank line after "public:"  [whitespace/blank_line] [3]
src/descriptor.pb.h:1637:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:1639:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:1662:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:1664:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:1673:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:1715:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:1717:  private: should be indented +1 space inside class MethodDescriptorProto  [whitespace/indent] [3]
src/descriptor.pb.h:1717:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:1722:  private: should be indented +1 space inside class MethodDescriptorProto  [whitespace/indent] [3]
src/descriptor.pb.h:1722:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:1729:  public: should be indented +1 space inside class MethodDescriptorProto  [whitespace/indent] [3]
src/descriptor.pb.h:1729:  "public:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:1730:  Do not leave a blank line after "public:"  [whitespace/blank_line] [3]
src/descriptor.pb.h:1820:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:1871:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:1873:  private: should be indented +1 space inside class FileOptions  [whitespace/indent] [3]
src/descriptor.pb.h:1873:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:1878:  private: should be indented +1 space inside class FileOptions  [whitespace/indent] [3]
src/descriptor.pb.h:1878:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:1885:  public: should be indented +1 space inside class FileOptions  [whitespace/indent] [3]
src/descriptor.pb.h:1885:  "public:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:1886:  Do not leave a blank line after "public:"  [whitespace/blank_line] [3]
src/descriptor.pb.h:1966:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2048:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2049:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2051:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2053:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2103:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2108:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2159:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2161:  private: should be indented +1 space inside class MessageOptions  [whitespace/indent] [3]
src/descriptor.pb.h:2161:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:2166:  private: should be indented +1 space inside class MessageOptions  [whitespace/indent] [3]
src/descriptor.pb.h:2166:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:2173:  public: should be indented +1 space inside class MessageOptions  [whitespace/indent] [3]
src/descriptor.pb.h:2173:  "public:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:2174:  Do not leave a blank line after "public:"  [whitespace/blank_line] [3]
src/descriptor.pb.h:2213:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2214:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2216:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2218:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2238:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2243:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2294:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2296:  private: should be indented +1 space inside class FieldOptions  [whitespace/indent] [3]
src/descriptor.pb.h:2296:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:2301:  private: should be indented +1 space inside class FieldOptions  [whitespace/indent] [3]
src/descriptor.pb.h:2301:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:2308:  public: should be indented +1 space inside class FieldOptions  [whitespace/indent] [3]
src/descriptor.pb.h:2308:  "public:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:2309:  Do not leave a blank line after "public:"  [whitespace/blank_line] [3]
src/descriptor.pb.h:2386:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2418:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2419:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2421:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2423:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2449:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2454:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2505:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2507:  private: should be indented +1 space inside class EnumOptions  [whitespace/indent] [3]
src/descriptor.pb.h:2507:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:2512:  private: should be indented +1 space inside class EnumOptions  [whitespace/indent] [3]
src/descriptor.pb.h:2512:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:2519:  public: should be indented +1 space inside class EnumOptions  [whitespace/indent] [3]
src/descriptor.pb.h:2519:  "public:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:2520:  Do not leave a blank line after "public:"  [whitespace/blank_line] [3]
src/descriptor.pb.h:2545:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2546:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2548:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2550:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2566:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2569:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2620:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2622:  private: should be indented +1 space inside class EnumValueOptions  [whitespace/indent] [3]
src/descriptor.pb.h:2622:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:2627:  private: should be indented +1 space inside class EnumValueOptions  [whitespace/indent] [3]
src/descriptor.pb.h:2627:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:2634:  public: should be indented +1 space inside class EnumValueOptions  [whitespace/indent] [3]
src/descriptor.pb.h:2634:  "public:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:2635:  Do not leave a blank line after "public:"  [whitespace/blank_line] [3]
src/descriptor.pb.h:2653:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2654:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2656:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2658:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2672:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2674:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2725:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2727:  private: should be indented +1 space inside class ServiceOptions  [whitespace/indent] [3]
src/descriptor.pb.h:2727:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:2732:  private: should be indented +1 space inside class ServiceOptions  [whitespace/indent] [3]
src/descriptor.pb.h:2732:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:2739:  public: should be indented +1 space inside class ServiceOptions  [whitespace/indent] [3]
src/descriptor.pb.h:2739:  "public:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:2740:  Do not leave a blank line after "public:"  [whitespace/blank_line] [3]
src/descriptor.pb.h:2758:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2759:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2761:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2763:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2777:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2779:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2830:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2832:  private: should be indented +1 space inside class MethodOptions  [whitespace/indent] [3]
src/descriptor.pb.h:2832:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:2837:  private: should be indented +1 space inside class MethodOptions  [whitespace/indent] [3]
src/descriptor.pb.h:2837:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:2844:  public: should be indented +1 space inside class MethodOptions  [whitespace/indent] [3]
src/descriptor.pb.h:2844:  "public:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:2845:  Do not leave a blank line after "public:"  [whitespace/blank_line] [3]
src/descriptor.pb.h:2863:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2864:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2866:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2868:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2882:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2884:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2893:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2900:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2935:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:2937:  private: should be indented +1 space inside class UninterpretedOption_NamePart  [whitespace/indent] [3]
src/descriptor.pb.h:2937:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:2942:  private: should be indented +1 space inside class UninterpretedOption_NamePart  [whitespace/indent] [3]
src/descriptor.pb.h:2942:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:2949:  public: should be indented +1 space inside class UninterpretedOption_NamePart  [whitespace/indent] [3]
src/descriptor.pb.h:2949:  "public:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:2950:  Do not leave a blank line after "public:"  [whitespace/blank_line] [3]
src/descriptor.pb.h:2991:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3000:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3042:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3044:  private: should be indented +1 space inside class UninterpretedOption  [whitespace/indent] [3]
src/descriptor.pb.h:3044:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:3049:  private: should be indented +1 space inside class UninterpretedOption  [whitespace/indent] [3]
src/descriptor.pb.h:3049:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:3056:  public: should be indented +1 space inside class UninterpretedOption  [whitespace/indent] [3]
src/descriptor.pb.h:3056:  "public:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:3057:  Do not leave a blank line after "public:"  [whitespace/blank_line] [3]
src/descriptor.pb.h:3073:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3075:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3153:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3160:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3169:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3176:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3211:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3213:  private: should be indented +1 space inside class SourceCodeInfo_Location  [whitespace/indent] [3]
src/descriptor.pb.h:3213:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:3218:  private: should be indented +1 space inside class SourceCodeInfo_Location  [whitespace/indent] [3]
src/descriptor.pb.h:3218:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:3225:  public: should be indented +1 space inside class SourceCodeInfo_Location  [whitespace/indent] [3]
src/descriptor.pb.h:3225:  "public:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:3226:  Do not leave a blank line after "public:"  [whitespace/blank_line] [3]
src/descriptor.pb.h:3294:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3295:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3313:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3314:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3365:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3367:  private: should be indented +1 space inside class SourceCodeInfo  [whitespace/indent] [3]
src/descriptor.pb.h:3367:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:3372:  private: should be indented +1 space inside class SourceCodeInfo  [whitespace/indent] [3]
src/descriptor.pb.h:3372:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:3379:  public: should be indented +1 space inside class SourceCodeInfo  [whitespace/indent] [3]
src/descriptor.pb.h:3379:  "public:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:3380:  Do not leave a blank line after "public:"  [whitespace/blank_line] [3]
src/descriptor.pb.h:3396:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3398:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3403:  Do not leave a blank line after "private:"  [whitespace/blank_line] [3]
src/descriptor.pb.h:3407:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3408:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3417:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3424:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3459:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3461:  private: should be indented +1 space inside class GeneratedCodeInfo_Annotation  [whitespace/indent] [3]
src/descriptor.pb.h:3461:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:3466:  private: should be indented +1 space inside class GeneratedCodeInfo_Annotation  [whitespace/indent] [3]
src/descriptor.pb.h:3466:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:3473:  public: should be indented +1 space inside class GeneratedCodeInfo_Annotation  [whitespace/indent] [3]
src/descriptor.pb.h:3473:  "public:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:3474:  Do not leave a blank line after "public:"  [whitespace/blank_line] [3]
src/descriptor.pb.h:3536:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3545:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3587:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3589:  private: should be indented +1 space inside class GeneratedCodeInfo  [whitespace/indent] [3]
src/descriptor.pb.h:3589:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:3594:  private: should be indented +1 space inside class GeneratedCodeInfo  [whitespace/indent] [3]
src/descriptor.pb.h:3594:  "private:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:3601:  public: should be indented +1 space inside class GeneratedCodeInfo  [whitespace/indent] [3]
src/descriptor.pb.h:3601:  "public:" should be preceded by a blank line  [whitespace/blank_line] [3]
src/descriptor.pb.h:3602:  Do not leave a blank line after "public:"  [whitespace/blank_line] [3]
src/descriptor.pb.h:3615:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3616:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3618:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3620:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3625:  Do not leave a blank line after "private:"  [whitespace/blank_line] [3]
src/descriptor.pb.h:3629:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3630:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3652:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3656:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3664:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3669:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3690:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3695:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3699:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3704:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3716:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3721:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3729:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3744:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3749:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3753:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3758:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3763:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3770:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3775:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3783:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3802:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3810:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3827:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3849:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3853:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3857:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3879:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3883:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3887:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3909:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3913:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3917:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3921:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3926:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3939:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3943:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3947:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3951:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3956:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3969:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3973:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3977:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3981:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3986:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:3999:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4003:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4007:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4011:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4016:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4036:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4055:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4077:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4080:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4082:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4084:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4092:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4099:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4121:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4126:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4130:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4135:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4140:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4147:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4152:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4160:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4186:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4210:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4238:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4262:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4283:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4288:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4292:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4297:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4309:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4314:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4322:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4333:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4337:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4345:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4350:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4363:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4367:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4371:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4375:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4380:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4393:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4397:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4405:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4410:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4423:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4427:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4431:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4435:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4440:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4453:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4457:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4461:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4465:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4470:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4483:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4487:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4491:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4495:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4500:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4520:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4539:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4557:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4561:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4565:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4569:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4574:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4595:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4603:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4650:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4655:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4659:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4664:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4676:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4681:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4689:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4731:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4735:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4756:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4760:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4778:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4783:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4787:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4792:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4795:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4797:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4804:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4809:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4811:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4817:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4832:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4837:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4841:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4846:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4851:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4858:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4863:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4865:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4871:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4886:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4891:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4893:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4895:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4900:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4903:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4905:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4912:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4917:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4919:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4925:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4947:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4964:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4969:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4973:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4978:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4981:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4983:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4990:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4995:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:4997:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5003:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5021:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5025:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5033:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5040:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5066:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5071:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5075:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5080:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5092:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5097:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5105:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5124:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5129:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5133:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5138:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5150:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5155:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5163:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5174:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5178:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5182:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5186:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5191:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5211:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5230:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5256:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5261:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5265:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5270:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5282:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5287:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5295:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5317:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5337:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5341:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5349:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5356:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5382:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5387:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5391:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5396:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5408:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5413:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5421:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5432:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5436:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5440:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5444:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5449:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5469:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5473:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5481:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5488:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5514:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5519:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5523:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5528:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5540:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5545:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5553:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5568:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5573:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5577:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5582:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5585:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5587:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5594:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5599:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5601:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5607:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5622:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5627:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5631:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5636:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5639:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5641:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5648:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5653:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5655:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5661:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5679:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5683:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5691:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5698:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5772:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5777:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5781:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5786:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5791:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5798:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5803:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5805:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5811:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5826:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5831:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5835:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5840:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5843:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5845:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5852:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5857:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5859:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5865:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5941:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5955:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5957:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5959:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5977:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5982:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5986:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5991:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:5996:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6003:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6008:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6016:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6151:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6156:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6160:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6165:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6170:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6177:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6182:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6184:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6190:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6205:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6210:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6214:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6219:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6224:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6231:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6236:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6238:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6244:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6255:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6259:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6263:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6267:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6272:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6385:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6389:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6393:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6397:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6402:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6430:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6461:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6479:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6565:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6569:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6573:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6577:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6582:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6647:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6651:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6655:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6659:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6664:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6705:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6709:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6713:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6717:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6722:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6763:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6767:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6771:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6775:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6780:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6821:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6825:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6829:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6833:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6838:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6859:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6864:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6866:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6868:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6873:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6876:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6878:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6885:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6890:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6892:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6898:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6937:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6941:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6945:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6949:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6954:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6971:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6976:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6978:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6980:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6985:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6988:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6990:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:6997:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7002:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7004:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7010:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7028:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7032:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7052:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7056:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7097:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7102:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7106:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7111:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7114:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7116:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7123:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7128:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7130:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7136:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7151:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7156:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7158:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7160:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7165:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7168:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7170:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7177:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7182:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7184:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7190:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7205:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7209:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7235:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7239:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7269:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7274:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7276:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7278:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7283:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7286:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7288:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7295:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7300:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7302:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7308:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7323:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7328:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7330:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7332:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7337:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7340:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7342:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7349:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7354:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7356:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7362:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7373:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7377:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7381:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7385:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7389:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7398:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7402:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7406:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7407:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7432:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7436:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7440:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7444:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7449:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7466:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7470:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7474:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7500:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7505:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7507:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7509:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7514:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7517:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7519:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7526:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7531:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7533:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7539:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7561:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7585:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7602:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7606:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7610:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7614:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7619:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7682:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7684:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7687:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7689:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7692:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7694:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7697:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7699:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7702:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor.pb.h:7704:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor_unittest.cc:43:  Found C system header after C++ system header. Should be: descriptor_unittest.h, c system, c++ system, other.  [build/include_order] [4]
src/descriptor_unittest.cc:44:  Found C system header after C++ system header. Should be: descriptor_unittest.h, c system, c++ system, other.  [build/include_order] [4]
src/descriptor_unittest.cc:45:  Found C system header after C++ system header. Should be: descriptor_unittest.h, c system, c++ system, other.  [build/include_order] [4]
src/descriptor_unittest.cc:46:  Found C system header after C++ system header. Should be: descriptor_unittest.h, c system, c++ system, other.  [build/include_order] [4]
src/descriptor_unittest.cc:47:  Found C system header after C++ system header. Should be: descriptor_unittest.h, c system, c++ system, other.  [build/include_order] [4]
src/descriptor_unittest.cc:48:  Found C system header after C++ system header. Should be: descriptor_unittest.h, c system, c++ system, other.  [build/include_order] [4]
src/descriptor_unittest.cc:49:  Found C system header after C++ system header. Should be: descriptor_unittest.h, c system, c++ system, other.  [build/include_order] [4]
src/descriptor_unittest.cc:50:  Found C system header after C++ system header. Should be: descriptor_unittest.h, c system, c++ system, other.  [build/include_order] [4]
src/descriptor_unittest.cc:51:  Found C system header after C++ system header. Should be: descriptor_unittest.h, c system, c++ system, other.  [build/include_order] [4]
src/descriptor_unittest.cc:52:  Found C system header after C++ system header. Should be: descriptor_unittest.h, c system, c++ system, other.  [build/include_order] [4]
src/descriptor_unittest.cc:53:  Found C system header after C++ system header. Should be: descriptor_unittest.h, c system, c++ system, other.  [build/include_order] [4]
src/descriptor_unittest.cc:55:  Found C system header after C++ system header. Should be: descriptor_unittest.h, c system, c++ system, other.  [build/include_order] [4]
src/descriptor_unittest.cc:56:  Found C system header after C++ system header. Should be: descriptor_unittest.h, c system, c++ system, other.  [build/include_order] [4]
src/descriptor_unittest.cc:57:  "google/protobuf/stubs/logging.h" already included at src/descriptor_unittest.cc:56  [build/include] [4]
src/descriptor_unittest.cc:58:  Found C system header after C++ system header. Should be: descriptor_unittest.h, c system, c++ system, other.  [build/include_order] [4]
src/descriptor_unittest.cc:59:  Found C system header after C++ system header. Should be: descriptor_unittest.h, c system, c++ system, other.  [build/include_order] [4]
src/descriptor_unittest.cc:60:  Found C system header after C++ system header. Should be: descriptor_unittest.h, c system, c++ system, other.  [build/include_order] [4]
src/descriptor_unittest.cc:734:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:735:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:822:  Extra space after ( in function call  [whitespace/parens] [4]
src/descriptor_unittest.cc:823:  Extra space after ( in function call  [whitespace/parens] [4]
src/descriptor_unittest.cc:825:  Extra space after ( in function call  [whitespace/parens] [4]
src/descriptor_unittest.cc:841:  Extra space before ( in function call  [whitespace/parens] [4]
src/descriptor_unittest.cc:846:  Extra space before ( in function call  [whitespace/parens] [4]
src/descriptor_unittest.cc:851:  Extra space before ( in function call  [whitespace/parens] [4]
src/descriptor_unittest.cc:1281:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:1282:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:1450:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:1451:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:1643:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:1644:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:1675:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:1676:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:1677:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:1681:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:1682:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:1694:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:1695:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:1783:  You don't need a ; after a }  [readability/braces] [4]
src/descriptor_unittest.cc:1828:  You don't need a ; after a }  [readability/braces] [4]
src/descriptor_unittest.cc:1831:  Extra space after ( in function call  [whitespace/parens] [4]
src/descriptor_unittest.cc:1832:  Extra space before ( in function call  [whitespace/parens] [4]
src/descriptor_unittest.cc:1833:  Extra space before ( in function call  [whitespace/parens] [4]
src/descriptor_unittest.cc:1836:  Extra space before ( in function call  [whitespace/parens] [4]
src/descriptor_unittest.cc:1837:  Extra space before ( in function call  [whitespace/parens] [4]
src/descriptor_unittest.cc:1847:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:1946:  You don't need a ; after a }  [readability/braces] [4]
src/descriptor_unittest.cc:1961:  You don't need a ; after a }  [readability/braces] [4]
src/descriptor_unittest.cc:1950:  Extra space before ( in function call  [whitespace/parens] [4]
src/descriptor_unittest.cc:1953:  Extra space before ( in function call  [whitespace/parens] [4]
src/descriptor_unittest.cc:1954:  Extra space before ( in function call  [whitespace/parens] [4]
src/descriptor_unittest.cc:1955:  Extra space before ( in function call  [whitespace/parens] [4]
src/descriptor_unittest.cc:1959:  Extra space before ( in function call  [whitespace/parens] [4]
src/descriptor_unittest.cc:1968:  You don't need a ; after a }  [readability/braces] [4]
src/descriptor_unittest.cc:1974:  You don't need a ; after a }  [readability/braces] [4]
src/descriptor_unittest.cc:1971:  Extra space before ( in function call  [whitespace/parens] [4]
src/descriptor_unittest.cc:1972:  Extra space before ( in function call  [whitespace/parens] [4]
src/descriptor_unittest.cc:2047:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2048:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2049:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2050:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2051:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2052:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2053:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2054:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2055:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2056:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2057:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2058:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2059:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2060:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2063:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2064:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2072:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2073:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2074:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2075:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2076:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2077:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2078:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2079:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2080:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2081:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2082:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2083:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2084:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2085:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2088:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2089:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2097:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2098:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2099:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2100:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2101:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2102:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2103:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2104:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2105:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2106:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2107:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2108:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2109:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2110:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2113:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2114:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2122:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2123:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2124:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2125:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2126:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2127:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2128:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2129:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2130:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2131:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2132:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2133:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2134:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2135:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2138:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2139:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2147:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2148:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2149:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2150:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2151:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2152:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2153:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2154:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2155:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2164:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2165:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2166:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2167:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2168:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2169:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2170:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2171:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2172:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2173:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2174:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2175:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2176:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2177:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2180:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2181:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2189:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2190:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2191:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2192:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2193:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2194:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2195:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2196:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2197:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2198:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2199:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2200:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2201:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2202:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2205:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2206:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2255:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2256:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2259:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2261:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2263:  Extra space before )  [whitespace/parens] [2]
src/descriptor_unittest.cc:2296:  Extra space before ( in function call  [whitespace/parens] [4]
src/descriptor_unittest.cc:2298:  Extra space before ( in function call  [whitespace/parens] [4]
src/descriptor_unittest.cc:2302:  Extra space before ( in function call  [whitespace/parens] [4]
src/descriptor_unittest.cc:2304:  Extra space after ( in function call  [whitespace/parens] [4]
src/descriptor_unittest.cc:2304:  Extra space before ( in function call  [whitespace/parens] [4]
src/descriptor_unittest.cc:2307:  Extra space before ( in function call  [whitespace/parens] [4]
src/descriptor_unittest.cc:2321:  Extra space before ( in function call  [whitespace/parens] [4]
src/descriptor_unittest.cc:2322:  Extra space before ( in function call  [whitespace/parens] [4]
src/descriptor_unittest.cc:2325:  Extra space before ( in function call  [whitespace/parens] [4]
src/descriptor_unittest.cc:2327:  Extra space after ( in function call  [whitespace/parens] [4]
src/descriptor_unittest.cc:2327:  Extra space before ( in function call  [whitespace/parens] [4]
src/descriptor_unittest.cc:2383:  Weird number of spaces at line-start.  Are you using a 2-space indent?  [whitespace/indent] [3]
src/descriptor_unittest.cc:2781:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor_unittest.cc:3038:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor_unittest.cc:3120:  Missing space after ,  [whitespace/comma] [3]
src/descriptor_unittest.cc:4475:  Closing ) should be moved to the previous line  [whitespace/parens] [2]
src/descriptor_unittest.cc:4489:  Closing ) should be moved to the previous line  [whitespace/parens] [2]
src/descriptor_unittest.cc:4502:  Closing ) should be moved to the previous line  [whitespace/parens] [2]
src/descriptor_unittest.cc:4516:  Closing ) should be moved to the previous line  [whitespace/parens] [2]
src/descriptor_unittest.cc:4548:  Closing ) should be moved to the previous line  [whitespace/parens] [2]
src/descriptor_unittest.cc:4984:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor_unittest.cc:4990:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/descriptor_unittest.cc:5125:  Closing ) should be moved to the previous line  [whitespace/parens] [2]
src/descriptor_unittest.cc:5273:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/descriptor_unittest.cc:5274:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/descriptor_unittest.cc:5276:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/descriptor_unittest.cc:5277:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/descriptor_unittest.cc:5929:  Single-parameter constructors should be marked explicit.  [runtime/explicit] [4]
src/descriptor_unittest.cc:5968:  Single-parameter constructors should be marked explicit.  [runtime/explicit] [4]
src/descriptor_unittest.cc:6401:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/descriptor_unittest.cc:6402:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/descriptor_unittest.cc:6403:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/descriptor_unittest.cc:6404:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/descriptor_unittest.cc:6405:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/descriptor_unittest.cc:6406:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/descriptor_unittest.cc:6407:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/descriptor_unittest.cc:6408:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/descriptor_unittest.cc:6409:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/descriptor_unittest.cc:6410:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/descriptor_unittest.cc:6411:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/descriptor_unittest.cc:6412:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/descriptor_unittest.cc:6413:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/descriptor_unittest.cc:6414:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/descriptor_unittest.cc:6416:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/descriptor_unittest.cc:6417:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/descriptor_unittest.cc:6418:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/descriptor_unittest.cc:6419:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/descriptor_unittest.cc:6420:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/descriptor_unittest.cc:6421:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/descriptor_unittest.cc:6422:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/descriptor_unittest.cc:6423:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/descriptor_unittest.cc:6424:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/descriptor_unittest.cc:6425:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/descriptor_unittest.cc:6426:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/descriptor_unittest.cc:6427:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/descriptor_unittest.cc:6428:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/descriptor_unittest.cc:6486:  Redundant blank line at the end of a code block should be deleted.  [whitespace/blank_line] [3]
src/descriptor_unittest.cc:6557:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/descriptor_unittest.cc:6558:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/descriptor_unittest.cc:6437:  Add #include <string> for string  [build/include_what_you_use] [4]

